Re: [PATCH v2] coccicheck: process every source file at once
- From
Jacob Keller <jacob.keller@gmail.com>
- Date
- Oct 2, 2018, 20:04 UTC
- Message-ID
- <CA+P7+xqWDyxR7jWQ-YEH2YUdCYQCg3KYpHEOnVcPY75XLrLxNw@mail.gmail.com>
- In-Reply-To
- <20181002200353.13412-1-jacob.e.keller@intel.com>
On Tue, Oct 2, 2018 at 1:03 PM Jacob Keller <jacob.e.keller@intel.com> wrote:
Show 30 quoted lines
> > From: Jacob Keller <jacob.keller@gmail.com> > > make coccicheck is used in order to apply coccinelle semantic patches, > and see if any of the transformations found within contrib/coccinelle/ > can be applied to the current code base. > > Pass every file to a single invocation of spatch, instead of running > spatch once per source file. > > This reduces the time required to run make coccicheck by a significant > amount of time: > > Prior timing of make coccicheck > real 6m14.090s > user 25m2.606s > sys 1m22.919s > > New timing of make coccicheck > real 1m36.580s > user 7m55.933s > sys 0m18.219s > > This is nearly a 4x decrease in the time required to run make > coccicheck. This is due to the overhead of restarting spatch for every > file. By processing all files at once, we can amortize this startup cost > across the total number of files, rather than paying it once per file. > > Signed-off-by: Jacob Keller <jacob.keller@gmail.com> > ---
Woops, ignore this version, it doesn't quite work.
Thanks, Jake